bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.compute_mask_to_parent
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.compute_mask_to_parent